"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const formatWebpackMessages_1 = __importDefault(require("react-dev-utils/formatWebpackMessages"));
const printBuildError_1 = __importDefault(require("react-dev-utils/printBuildError"));
const webpack_1 = __importDefault(require("webpack"));
const WebpackDevServerUtils_1 = require("react-dev-utils/WebpackDevServerUtils");
const config_1 = require("./config");
process.env.BABEL_ENV = 'production';
process.env.NODE_ENV = 'production';
process.on('unhandledRejection', err => {
    throw err;
});
const bootstrap = () => __awaiter(void 0, void 0, void 0, function* () {
    const config = yield config_1.createWebpackConfig('production');
    const appName = require(config_1.paths.appPackageJson).name;
    const compiler = WebpackDevServerUtils_1.createCompiler({
        webpack: webpack_1.default,
        config,
        appName,
        useYarn: true,
        urls: {},
    });
    return new Promise((resolve, reject) => {
        compiler.run((error, stats) => {
            let messages;
            if (error) {
                if (!error.message) {
                    return reject(error);
                }
                messages = formatWebpackMessages_1.default({
                    errors: [error.message],
                    warnings: [],
                });
            }
            else {
                messages = formatWebpackMessages_1.default(stats.toJson({ all: false, warnings: true, errors: true }));
            }
            if (messages.errors.length) {
                if (messages.errors.length > 1) {
                    messages.errors.length = 1;
                }
                return reject(new Error(messages.errors.join('\n\n')));
            }
            return resolve({
                stats,
                warnings: messages.warnings,
            });
        });
    });
});
const handleStat = ({ warnings }) => {
    if (warnings.length) {
        console.log(chalk_1.default.yellow('Compiled with warnings.\n'));
        console.log(warnings.join('\n\n'));
        console.log(`\nSearch for the ${chalk_1.default.underline(chalk_1.default.yellow('keywords'))} to learn more about each warning.`);
        console.log(`To ignore, add ${chalk_1.default.cyan('// eslint-disable-next-line')} to the line before.\n`);
    }
    else {
        console.log(chalk_1.default.green('Compiled successfully.\n'));
    }
};
const handleErrors = error => {
    console.log(chalk_1.default.red('Failed to compile.\n'));
    printBuildError_1.default(error);
    process.exit(1);
};
bootstrap()
    .then(handleStat)
    .catch(handleErrors);
