"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWebpackConfig = void 0;
const start_server_webpack_plugin_1 = __importDefault(require("start-server-webpack-plugin"));
const glob_promise_1 = __importDefault(require("glob-promise"));
const webpack_node_externals_1 = __importDefault(require("webpack-node-externals"));
const webpack_1 = require("webpack");
const path_1 = require("path");
const project_1 = require("@lerna/project");
const paths_1 = __importDefault(require("./paths"));
const createWebpackConfig = (webpackEnv) => __awaiter(void 0, void 0, void 0, function* () {
    const isEnvDevelopment = webpackEnv === 'development';
    const isEnvProduction = webpackEnv === 'production';
    const packages = yield project_1.getPackages(process.cwd());
    const workspaces = packages.map(({ name }) => new RegExp(name));
    const configs = yield glob_promise_1.default(path_1.join(paths_1.default.appConfigsPath, '**/*.ts'));
    const configEntries = configs.reduce((result, config) => (Object.assign(Object.assign({}, result), { [path_1.relative(paths_1.default.appSrc, config).replace('.ts', '')]: [
            isEnvDevelopment && 'webpack/hot/poll?100',
            config,
        ].filter(Boolean) })), {});
    return {
        mode: isEnvProduction ? 'production' : isEnvDevelopment && 'development',
        bail: isEnvProduction,
        target: 'node',
        entry: Object.assign({ index: [isEnvDevelopment && 'webpack/hot/poll?100', paths_1.default.appIndex].filter(Boolean) }, configEntries),
        output: {
            path: paths_1.default.appBuild,
            pathinfo: isEnvDevelopment,
            libraryTarget: 'commonjs',
            filename: '[name].js',
            publicPath: '/',
        },
        module: {
            rules: [
                {
                    test: /.tsx?$/,
                    exclude: /node_modules/,
                    loader: require.resolve('ts-loader'),
                    options: {
                        transpileOnly: true,
                        experimentalWatchApi: true,
                    },
                },
            ],
        },
        externals: [
            webpack_node_externals_1.default({
                allowlist: [...workspaces, 'webpack/hot/poll?100'],
            }),
            webpack_node_externals_1.default({
                modulesDir: paths_1.default.rootNodeModules,
                allowlist: [...workspaces, 'webpack/hot/poll?100'],
            }),
        ],
        resolve: {
            extensions: ['.tsx', '.ts', '.js'],
        },
        plugins: [
            isEnvDevelopment && new webpack_1.HotModuleReplacementPlugin(),
            isEnvDevelopment &&
                new start_server_webpack_plugin_1.default({
                    name: 'index.js',
                    nodeArgs: ['--require=ts-node/register'],
                }),
        ].filter(Boolean),
        node: {
            __dirname: false,
        },
        optimization: {
            minimize: false,
        },
    };
});
exports.createWebpackConfig = createWebpackConfig;
